# w.c.s. - web application for online forms
# Copyright (C) 2005-2020  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

from wcs.qommon.xml_storage import XmlStorableObject


class ApiAccess(XmlStorableObject):
    _names = 'apiaccess'
    xml_root_node = 'apiaccess'
    name = None
    access_identifier = None
    access_key = None
    description = None
    restrict_to_anonymised_data = False
    _roles = None

    # declarations for serialization
    XML_NODES = [
        ('name', 'str'),
        ('description', 'str'),
        ('access_identifier', 'str'),
        ('access_key', 'str'),
        ('restrict_to_anonymised_data', 'bool'),
        ('roles', 'roles'),
    ]

    @classmethod
    def get_by_identifier(cls, access_identifier):
        for api_access in cls.select():
            if api_access.access_identifier == access_identifier:
                return api_access
        return None

    @classmethod
    def get_access_key(cls, access_identifier):
        api_access = cls.get_by_identifier(access_identifier)
        if api_access:
            return api_access.access_key
        return None

    def get_roles(self):
        return self.roles or []

    def get_as_api_user(self):
        class RestrictedApiUser:
            # kept as inner class so cannot be pickled
            id = Ellipsis  # make sure it fails all over the place if used
            is_admin = False
            is_api_user = True
            anonymous = False

            def __init__(self, api_access):
                self.api_access = api_access

            def can_go_in_admin(self):
                return False

            def can_go_in_backoffice(self):
                return False

            def get_roles(self):
                return self.roles

        user = RestrictedApiUser(self)
        user.roles = [x.id for x in self.get_roles()]
        return user

    @classmethod
    def get_with_credentials(cls, username, password):
        api_access = cls.get_by_identifier(username)
        if not api_access or api_access.access_key != password:
            raise KeyError
        return api_access.get_as_api_user()

    @property
    def roles(self):
        return self._roles() if callable(self._roles) else self._roles

    @roles.setter
    def roles(self, value):
        self._roles = value
