# w.c.s. - web application for online forms
# Copyright (C) 2005-2022  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

from wcs.qommon import _
from wcs.qommon.form import CheckboxWidget
from wcs.workflows import WorkflowStatusItem

# RedirectToStatusWorkflowStatusItem is not registered as the class kept for
# backward compatibility only and should not be exposed to the user. (#3031)


class RedirectToStatusWorkflowStatusItem(WorkflowStatusItem):
    description = _('Status Page Redirection')
    key = 'redirectstatus'
    ok_in_global_action = False

    backoffice = False

    def perform(self, formdata):
        return formdata.get_url(self.backoffice)

    def add_parameters_widgets(self, form, parameters, prefix='', formdef=None, **kwargs):
        super().add_parameters_widgets(form, parameters, prefix=prefix, formdef=formdef, **kwargs)
        if 'backoffice' in parameters:
            form.add(
                CheckboxWidget,
                '%sbackoffice' % prefix,
                title=_('Redirect to backoffice page'),
                value=self.backoffice,
            )

    def get_parameters(self):
        return ('backoffice',)
